import java.awt.*;
import java.awt.geom.*;
import javax.swing.*;

import app.*;
import io.*;
import visual.*;
import visual.dynamic.described.*;
import visual.statik.sampled.*;

/**
 * An example that illustrates the use of multiple views
 *
 * @author  Prof. David Bernstein, James Madison University
 * @see     "The Design and Implementation of Multimedia Software  2011"
 * @version 1.0
 *
 */
public class   DynamicJumboTronApp
       extends AbstractMultimediaApp
{
    /**
     * The entry point
     */
    public void init()
    {
       BuzzyOnMars                    buzzy;
       Content                        mars;
       ContentFactory                 factory;
       JPanel                         contentPane;       
       ResourceFinder                 finder;       
       ScaledVisualizationRenderer    renderer2;       
       Stage                          stage;
       VisualizationView              view1, view2;       

       finder  = ResourceFinder.createInstance(this);
       factory = new ContentFactory(finder);       

       // The Stage for Buzzy
       stage = new Stage(50);
       stage.setBackground(Color.white);
       stage.setRestartTime(7000);
       view1 = stage.getView();
       view1.setBounds(0,0,640,480);       
       
       renderer2 = new ScaledVisualizationRenderer(
                       new PlainVisualizationRenderer(), 640.0, 480.0);
       view2 = new VisualizationView(stage, renderer2);       
       view2.setBounds(50,50,160,120);       
       stage.addView(view2);
       
       mars = factory.createContent("mars.png");
       stage.add(mars);

       // Buzzy
       buzzy = new BuzzyOnMars();
       stage.add(buzzy);

       // The content pane
       contentPane = (JPanel)rootPaneContainer.getContentPane();
       contentPane.add(view2);
       contentPane.add(view1);

       stage.start();
    }
}
