import java.awt.*;
import java.awt.geom.*;
import java.awt.image.*;
import javax.swing.*;

import app.*;
import io.*;
import visual.VisualizationView;
import visual.dynamic.described.*;
import visual.statik.sampled.*;

/**
 * An example of described dynamic visual content that uses: several
 * RuleBasedSprite objects, and interaction
 *
 * @author  Prof. David Bernstein, James Madison University
 * @see     "The Design and Implementation of Multimedia Software  2011"
 * @version 1.0
 */
public class   FishTankApp
       extends AbstractMultimediaApp
{
    /**
     * The entry point
     */
    public void init()
    {
       BufferedImage                image;
       Content                      content;
       ContentFactory               factory;       
       Fish                         fish, shark;
       ImageFactory                 imageFactory;
       int                          height, width;       
       JPanel                       contentPane;       
       ResourceFinder               finder;       
       Stage                        stage;
       VisualizationView            stageView;       

//[skeleton
       width  = 640;
       height = 480;       

       finder       = ResourceFinder.createInstance(this);       
       factory      = new ContentFactory(finder);       
       imageFactory = new ImageFactory(finder);

       // The Stage
       stage = new Stage(50);
       stage.setBackground(Color.blue);
       content = factory.createContent("ocean.png", 3, false);
       stage.add(content);
       stageView = stage.getView();
       stageView.setBounds(0,0,width,height);       

       // The Shark
       content = factory.createContent("shark.png", 4, false);
       shark = new Fish(content, width, height, 8.);
       stage.add(shark);

       // The school of Fish
       // (Use the same BufferedImage object for all Fish)
       image   = imageFactory.createBufferedImage("fish.png", 4);
       for (int i=0; i<10; i++)
       {
	  content = factory.createContent(image, false);
          fish = new Fish(content, width, height, 3.);
          fish.addAntagonist(shark);       
          stage.add(fish);
       }
       
       // The content pane
       contentPane = (JPanel)rootPaneContainer.getContentPane();
       contentPane.add(stageView);

       stage.start();
//]skeleton
    }
}
