import java.awt.*;
import javax.swing.*;

import app.*;
import visual.*;
import io.ResourceFinder;
import visual.dynamic.sampled.Screen;
import visual.statik.SimpleContent;
import visual.statik.sampled.ContentFactory;

/**
 * An example that illustrates the use of multiple views
 *
 * @author  Prof. David Bernstein, James Madison University
 * @see     "The Design and Implementation of Multimedia Software  2011"
 * @version 1.0
 *
 */
public class   ScreenPIPApp
       extends AbstractMultimediaApp
{
    /**
     * The entry point
     */
    public void init()
    {
       ContentFactory                        factory;       
       JPanel                                contentPane;
       MovingRectangle                       mr;       
       ResourceFinder                        finder;       
       Screen                                screen1, screen2;
       SimpleContent[]                       frames1, frames2;
       String                                arg;       
       String[]                              names;       
       VisualizationView                     view1, view2;

       finder = ResourceFinder.createInstance(this);
       
       screen1 = new Screen();
       screen1.setRepeating(true);
       
       view1 = screen1.getView();       
       view1.setBounds(0,0,320,240);       

       names = finder.loadResourceNames("scribble.txt");
       factory = new ContentFactory(finder);          

       frames1 = factory.createContents(names, 4);
       for (int i=0; i<frames1.length; i++)
       {
          screen1.add(frames1[i]);          
       }
       
       screen2 = new Screen();
       screen2.setRepeating(true);
       
       view2 = screen2.getView();       
       view2.setRenderer(new ScaledVisualizationRenderer(view2.getRenderer(),
                                                         200.0, 200.0));       
       view2.setBounds(200,10,75,75);     
       view2.setSize(75,75);       

       mr      = new MovingRectangle();          
       frames2 = mr.getFrames();          

       for (int i=0; i<frames2.length; i++)
       {
          screen2.add(frames2[i]);          
       }
       
       // The content pane
       contentPane = (JPanel)rootPaneContainer.getContentPane();
       contentPane.add(view2);
       contentPane.add(view1);
          
       
       screen1.start();
       screen2.start();
    }
}
