import java.awt.*;
import java.awt.geom.*;
import javax.swing.*;

/**
 * A GUI component that displays the front wall of a classroom
 * with a "movie" screen (that can be partially lowered)
 */
public class FrontWallWithScreen extends FrontWall
{
    protected double               amountLowered;                      
    protected Rectangle2D.Double   screen;                    

    /**
     * Default Constructor
     */
    public FrontWallWithScreen()
    {
       super();
       screen = new Rectangle2D.Double();
    }

    /**
     * Render this component
     *
     * @param g   The rendering engine to use
     */
    public void paint(Graphics g)
    {
       Graphics2D      g2;

       super.paint(g);       
       g2 = (Graphics2D)g;
       renderScreen(g2);
    }
    
    /**
     * Set how low the movie screen is (i.e., what percentage of the
     * height of the front wall is covered by the movie screen)
     *
     * @param amountLowered    The percentage lowered (in the interval [0, 1])
     */
    public void setAmountLowered(double amount)
    {
       if ((amount >= 0.0) && (amount <= 1.0)) amountLowered = amount;
    }

    /**
     * Change the amount that the screen is lowered
     *
     * @param change    The amount of the change
     */
    public void changeAmountLowered(double change)
    {
       setAmountLowered(amountLowered + change);
    }
    



    /**
     * Render the "movie" screen on the front wall.
     *
     * The "movie" screen must be half as wide as the front wall and
     * must ocupy the middle half of the wall (i.e., the left-most
     * quarter of the wall and the right-most quarter of the wall must
     * never be covered by the screen).
     *
     * The screen must be fully raised when amountLowered is 0.0,
     * partially lowered when amountLowered is between 0.0 and 1.0
     * (e.g., when amountLowered is .28 it must be 28% lowered), and
     * fully lowered when amountLowered is 1.0.
     *
     * @param g2         The rendering engine to use
     */
    protected void renderScreen(Graphics2D g2)
    {

       // YOUR CODE HERE!

    }


}
