import java.awt.*;
import java.awt.geom.*;
import javax.swing.*;

/**
 * A GUI component that displays the front wall of a classroom.  The way 
 * in which this component is rendered depends on whether lightsOn is true
 * or false (simulating the lights in the room being on or off).
 */
public class FrontWallWithScreenAndLights extends FrontWallWithScreen
{
    protected boolean              lightsOn = true;   
    
    /**
     * Default Constructor
     */
    public FrontWallWithScreenAndLights()
    {
       super();
       setBackground(new Color(102,102,102)); // Dark grey
    }

    /**
     * Render this component
     *
     * @param g   The rendering engine to use
     */
    public void paint(Graphics g)
    {
       Graphics2D      g2;
       
       super.paint(g);       
       g2 = (Graphics2D)g;
       renderBackground(g2);
       renderScreen(g2);
    }

    /**
     * Turn the lights off
     */
    public void turnLightsOff()
    {
       lightsOn = false;
       repaint();
    }

    /**
     * Turn the lights on
     */
    public void turnLightsOn()
    {
       lightsOn = true;
       repaint();
    }
    
    
    /**
     * Render the background image on this component.
     *
     * The way in which the image is composed with the background
     * depends on the value of the lightsOn attribute.  When lightsOn
     * is true the image must be rendered "as is", whereas when
     * lightsOn is false it must appear to be "darker".
     *
     * @param g2         The rendering engine to use
     */
    protected void renderBackground(Graphics2D g2)
    {

       // YOUR CODE HERE!

    }
    
}
