package app;

import java.io.*;

/**
 * A utility for building MultimediaApplets and 
 * MultimediaAplications
 *
 * @author  Prof. David Bernstein, James Madison University
 * @see     "The Design and Implementation of Multimedia Software  2011"
 * @version 1.0
 */
public class Builder
{
    private static String          description, height, name, pkg, width;    
    
    private static String www = 
    "https://users.cs.jmu.edu/bernstdh/web/common/lectures/javaexamples/";

    private static String local = 
    "file:///c:/users/bernstdh/jmu/bernsteinmaterials/lectures/javaexamples/";
    
    /**
     * <p>
     * The entry point
     * </p>
     *
     * <p>
     * Command-line arguments:
     * </p>
     *
     * <ul>
     *   0 - The package <br />
     *   1 - The name of the App <br />
     *   2 - The width <br />
     *   3 - the height <br />
     *   4 - description (in quotes) <br />
     * </ul>
     *
     * @param args  The command-line arguments
     */
    public static void main(String[] args) throws Exception
    {
       PrintStream    out;

       pkg         = args[0];
       name        = args[1];
       width       = args[2];
       height      = args[3];
       description = args[4];

       out = new PrintStream(new FileOutputStream(name+"lication.java"));
       printApplication(out);       
       out.close();
       
       out = new PrintStream(new FileOutputStream(name+"let.java"));
       printApplet(out);       
       out.close();

       out = new PrintStream(
                 new FileOutputStream(name.toLowerCase()+"let.html"));
       printHTML(out, www);       
       out.close();

       out = new PrintStream(
                 new FileOutputStream(name.toLowerCase()+"let-local.html"));
       printHTML(out, local);       
       out.close();
    }


    /**
     * Print an array of lines
     */
    private static void print(PrintStream out, String[] lines)
    {
       for (int i=0; i<lines.length; i++) out.println("\t"+lines[i]);
    }

    /**
     * Print an individual line
     */
    private static void print(PrintStream out, String line)
    {
       out.println("\t"+line);
    }

    /**
     * Print an applet
     */
    private static void printApplet(PrintStream out)
    {
       print(out, "package " + pkg + ";");
       print(out, "");
       print(out, appletHeader);
       print(out, "* " + description);
       print(out, credits);
       print(out, "public class   " + name + "let");
       print(out, "       extends MultimediaApplet");
       print(out, "{");
       print(out, appletConstructor);
       print(out, "public " + name + "let()");
       print(out, "{");
       print(out, "super(new " + name + "());");
       print(out, "}");
       print(out, "}");
    }
    
    /**
     * Print an application
     */
    private static void printApplication(PrintStream out)
    {
       print(out, "package " + pkg + ";");
       print(out, "");
       print(out, applicationHeader);
       print(out, "* " + description);
       print(out, credits);
       print(out, "public class   " + name + "lication");
       print(out, "       extends MultimediaApplication");
       print(out, main);
       print(out, "          new " + name + "lication" +
                  "(args, " + width + ", " + height + "));");
       print(out, "}");
       print(out, "");
       print(out, "");
       print(out, applicationConstructor);
       print(out, "public " + name + "lication(String[] args,");
       print(out, "                            int width, int height)");
       print(out, "{");
       print(out, "super(args, new " + name + "(), width, height);");
       print(out, "}");
       print(out, "}");
    }

    /**
     * Print the HTML skeleton
     */
    private static void printHTML(PrintStream out, String location)
    {
       print(out, "<html>");
       print(out, "<body>");
       print(out, "<applet code=\""+pkg+"." + 
                    name + "let.class\"");
       print(out, "codebase=\"" + location + "\"");
       print(out, "width=\"" + width + "\" height=\"" + height + "\">");
       print(out, "</applet>");
       print(out, "</body>");
       print(out, "</html>");
    }
    
    private static final String[] appletHeader = 
    {
       "import java.io.*;",
       "import java.net.*;",
       "",
       "import app.*;",
       "",
       "",
       "/**",
       "* An example that illustrates"
    };

    private static final String[] applicationHeader = 
    {
       "import java.io.*;",
       "import java.net.*;",
       "import javax.swing.*;",
       "",
       "import app.*;",
       "",
       "",
       "/**",
       "* An example that illustrates"
    };
    
    public static final String[] credits = 
    {
       "*",
       "* @author  Prof. David Bernstein, James Madison University",
       "* @version 1.0",
       "*/"
    };

    public static final String[] main =
    {
       "{",
       "/**",
       "* The entry-point of the application",
       "*",
       "* @param args    The command-line arguments",
       "*/",
       "public static void main(String[] args) throws Exception",
       "{",
       "SwingUtilities.invokeAndWait("
    };
    
    public static final String[] appletConstructor = 
    {
       "/**",
       "* Default Constructor",
       "*/"
    };
    
    public static final String[] applicationConstructor = 
    {
       "/**",
       "* Explicit Value Constructor",
       "*",
       "* @param args    The command-line arguments",
       "* @param width   The width of the content (in pixels)",
       "* @param height  The height of the content (in pixels)",
       "*/"
    };
}
