import auditory.sampled.*;
import io.*;

import java.io.*;

/**
 * An app that renders sampled audio from a file
 *
 * @author  Prof. David Bernstein, James Madison University
 * @see     "The Design and Implementation of Multimedia Software  2011"
 * @version 1.0
 */
public class FilePlayerApp extends AbstractSampledAuditoryApp
{
    /**
     * Create the BufferedSound
     * (required by AbstractSampledAuditoryApp)
     *
     * @return   The BufferedSound
     */
    protected BufferedSound createSound()
    {
       BufferedSound             sound;       
       BufferedSoundFactory      factory;       
       ResourceFinder            finder;       
       String                    name;       

       name    = rootPaneContainer.getParameter("0");       
       finder  = ResourceFinder.createInstance(this);
       factory = new BufferedSoundFactory(finder);

       try
       {
          sound   = factory.createBufferedSound(name);
       }
       catch (Exception e)
       {
         sound = factory.createBufferedSound(200,     // frequency
                                              250000,  // length
                                              4000.0f, // sampling rate
                                              1000.0f  // amplitude
                                              );
       }
       
       return sound;
    }
}

